<!doctype html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <title>Styleguide</title>
</head>
<body>

    <h1>Opa Styleguide</h1>

    {{ styleguide }}

    {% for module in styleguide.modules %}
        <h2>Module: {{ module.name }}</h2>

        {% for component in module.components %}
            <section>
                <h3><a href="{{component.link}}">{{ component.name }}</a></h3>

                {% include component.template %}
            </section>
        {% endfor %}

    {% endfor %}

</body>

</html>
